Keen | Buttons
Description: Bootstrap extended buttons examples

# Customer Relationship Management

New Order

### Buttons

Reports
Keen extends `Bootstrap Button` component with a variety of options to provide uniquely looking Button component that matches the Keen's design standards.
For more info please visit the plugin's Documentation.

### Basic Buttons

Bootstrap buttons:
The `.btn` classes are designed to be used with `<button>`, `<a>` and `<input>` elements.
Link
Metal
Button states:
Keen custom buttons:
Keen base buttons:

### Button Customization

Large buttons:
Small buttons:
Font settings:
Wide buttons:
Tall buttons:

### Outline Buttons

Default outline buttons:
Hover outline buttons:

### Elevated Buttons

Default effect:
Hover air effect:

### Pill Buttons

Default options:
Elevation options:

### Square Buttons

Default options:
Elevation options:

### With Icons

Default options with Fontawesome 5 icons:
Elevation options with Lineawesome icons:
Pill options with Flaticon icons:
Size options:
Social network solid buttons:
Facebook Twitter Google Instagram Linkedin
Social network label buttons:
Facebook Twitter Google Instagram Linkedin

### Icon Only

Default options with Fontawesome 5 icons:
Elevation options with Lineawesome icons:
Circle options with Flaticon icons:
Size options:
Social network icon buttons:

### Label Style

You can use the buttons styles for labels with `span` tag:
Primary Success Info Danger Warning
Label pill style:
Primary Success Info Danger Warning
Link labels:
Primary Success Info Danger Warning
Label sizing:
Primary Success Info Danger Warning

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!